
---------------------------------------------------------------------------------------

local tileMapWidth = 8
local tileMapHeight = 8

local function load(tileMap)
  for i = 1, tileMapWidth do
    for j = 1, tileMapHeight do
	  tileMap:setTile(i, j, 1, 1)
    end
  end
end

local texture = Texture.new("assets/side_checkerboard_temp.png")

function loadTilemap()
  local tileMap = TileMap.new(tileMapWidth, tileMapHeight, texture, 16, 16)
  load(tileMap)

  return tileMap
end

local keysPressed = {
  up = false,
  down = false,
  left = false,
  right = false,
  zoom_in = false,
  zoom_out = false,
}

---------------------------------------------------------------------------------------

local function moveCamera(x, y, z, delta)
  tileMap:setX(tileMap:getX() + 30 * x * delta)
  tileMap:setY(tileMap:getY() + 30 * y * delta)
  tileMap:setZ(tileMap:getZ() + 30 * z * delta)
end

local function onEnterFrame(event)
  if keysPressed.up then
    moveCamera(0, 10, 0, event.deltaTime)
  end
  if keysPressed.down then
    moveCamera(0, -10, 0, event.deltaTime)
  end
  if keysPressed.left then
    moveCamera(10, 0, 0, event.deltaTime)
  end
  if keysPressed.right then
    moveCamera(-10, 0, 0, event.deltaTime)
  end
  if keysPressed.zoom_in then
    moveCamera(0, 0, 10, event.deltaTime)
  end
  if keysPressed.zoom_out then
    moveCamera(0, 0, -10, event.deltaTime)
  end
end

---------------------------------------------------------------------------------------

local function setKeys(event, value)
  if event.keyCode == KeyCode.UP then
    keysPressed.up = value
  end
  if event.keyCode == KeyCode.DOWN then
    keysPressed.down = value
  end
  if event.keyCode == KeyCode.LEFT then
    keysPressed.left = value
  end
  if event.keyCode == KeyCode.RIGHT then
    keysPressed.right = value
  end
  if event.keyCode == KeyCode.A then
    keysPressed.zoom_in = value
  end
  if event.realCode == KeyCode.Z then
    keysPressed.zoom_out = value
  end
end

---------------------------------------------------------------------------------------

local function onStageKeyDown(stage, event)
  setKeys(event, true)
end

local function onStageKeyUp(stage, event)
  setKeys(event, false)
end

---------------------------------------------------------------------------------------
---------------------------------------------------------------------------------------

local function onLoad()
  application:configureFrustum(90, 750)

  stage:addEventListener(Event.ENTER_FRAME, onEnterFrame)

  stage:addEventListener(Event.KEY_DOWN, onStageKeyDown, stage)
  stage:addEventListener(Event.KEY_UP, onStageKeyUp, stage)
  
  tileMap = loadTilemap()
  tileMap:setZ(-350)
  tileMap:setScale(10, 10)
  stage:addChild(tileMap)
end

---------------------------------------------------------------------------------------
---------------------------------------------------------------------------------------

onLoad()
